@@ -23,16 +23,11 @@ sys.path.append(dir_mtree)
 
 # import setup
 #import importlib.machinery
+import tools
 from tools import *
 
-dir_setup = os.path.abspath(os.path.join(dir_prosodic,'..'))
-path_setup = os.path.join(dir_setup,'setup.py')
-#module_setup = importlib.machinery.SourceFileLoader('setup',path_setup).load_module()
-#module_setup.configure_home_dir(force=False)
-configure_home_dir(force=False)
-
-path_setup = os.path.join(dir_prosodic)
-
+if 'configure_home_dir' in set(dir(tools)):
+	tools.configure_home_dir(force=False)
 ## import necessary objects
 toprintconfig=__name__=='__main__'
 #toprintconfig=True
@@ -88,11 +83,8 @@ for lng in languages:
 del lng
 
 
-## load config
-if __name__ != "__main__":
-	being.printout=False
-	#config['print_to_screen']=0
-else:	## if not imported, go into interactive mode
+def start_interactive_mode():
+	global lang
 	skip=False
 
 	## but do not go into interactive mode if only a single argument
@@ -146,7 +138,7 @@ else:	## if not imported, go into interactive mode
 		## welcome
 		print("")
 		print("################################################")
-		print("## welcome to prosodic!                  v1.3 ##")
+		print("## welcome to prosodic!                  v1.5 ##")
 		print("################################################")
 		print("")
 		text=""
@@ -595,3 +587,10 @@ else:	## if not imported, go into interactive mode
 		if cmd:
 			text=cmd
 			cmd=""
+
+## load config
+if __name__ != "__main__":
+	being.printout=False
+	#config['print_to_screen']=0
+else:	## if not imported, go into interactive mode
+	start_interactive_mode()
\ No newline at end of file
